.. py:currentmodule:: rubin_sim

.. _api:

API
===

.. toctree::
    :maxdepth: 2

    Data <data-api>

    Metrics Analysis Framework (MAF) <maf-api>

    Moving Objects <moving-objects-api>

    Phot Utils <phot-utils-api>

    Satellite Constellations <satellite-constellations-api>

    Self Calibration <selfcal-api>

    Skybrightness <skybrightness-api>